==> dpsrc.2008_10_02.tar.gz: libplot_src.f <==
      SUBROUTINE PLDRAW(IX1,IY1,IX2,IY2,JCOL,JPATT)
      RETURN
      END
      SUBROUTINE PLLATR(INDEX,ICODE,DVAL)
      INTEGER INDEX
      INTEGER ICODE
      DOUBLE PRECISION DVAL
      RETURN
      END
      SUBROUTINE PLPOIN(DX,DY)
      DOUBLE PRECISION DX
      DOUBLE PRECISION DY
      RETURN
      END
      SUBROUTINE PLEND(IERROR)
      INTEGER IERROR
      RETURN
      END
      SUBROUTINE PLRGFL(DX1,DY1,DX2,DY2)
      DOUBLE PRECISION DX1
      DOUBLE PRECISION DX2
      DOUBLE PRECISION DY1
      DOUBLE PRECISION DY2
      RETURN
      END
      SUBROUTINE PLSECO(RED,GHREEN,BLUE)
      DOUBLE PRECISION RED
      DOUBLE PRECISION GREEN
      DOUBLE PRECISION BLUE
      RETURN
      END
      SUBROUTINE PLSEPA(INDEX)
      RETURN
      END
      SUBROUTINE PLTXTH(IFONT,ISTRNG,XPOS,YPOS,IJUSTH,IJUSTV,
     1                  PHEIGH,IERROR)
      INTEGER ISTRNG(*)
      INTEGER IFONT(*)
      INTEGER IJUSTH
      INTEGER IJUSTV
      INTEGER IERROR
      DOUBLE PRECISION XPOS
      DOUBLE PRECISION YPOS
      DOUBLE PRECISION PHEIGH
      RETURN
      END
      SUBROUTINE PLTXTV(IFONT,ISTRNG,XPOS,YPOS,IJUSTH,IJUSTV,
     1                  PHEIGH,IERROR)
      INTEGER ISTRNG(*)
      INTEGER IFONT(*)
      INTEGER IJUSTH
      INTEGER IJUSTV
      INTEGER IERROR
      DOUBLE PRECISION XPOS
      DOUBLE PRECISION YPOS
      DOUBLE PRECISION PHEIGH
      RETURN
      END
      SUBROUTINE PLINIT(ITYPE,IERROR)
      INTEGER ITYPE
      INTEGER IERROR
      WRITE(*,*) ' THE LIBPLOT DRIVER HAVE NOT BEEN INSTALLED AT YOUR'
      WRITE(*,*) ' SITE.  CONTACT YOUR LOCAL SITE COORDINATER FOR '
      WRITE(*,*) ' MORE INFORMATION'
      IERROR=1
      RETURN
      END
      SUBROUTINE PLERAS(IADE,IRED,IGREEN,IBLUE)
      INTEGER IADE(*)
      RETURN
      END

==> dpsrc_2009_08_21.tar.gz: libplot_src.f <==
      SUBROUTINE PLDRAW(IX1,IY1,IX2,IY2,JCOL,JPATT)
      RETURN
      END
      SUBROUTINE PLLATR(INDEX,ICODE,DVAL)
      INTEGER INDEX
      INTEGER ICODE
      DOUBLE PRECISION DVAL
      RETURN
      END
      SUBROUTINE PLPOIN(DX,DY)
      DOUBLE PRECISION DX
      DOUBLE PRECISION DY
      RETURN
      END
      SUBROUTINE PLEND(IERROR)
      INTEGER IERROR
      RETURN
      END
      SUBROUTINE PLRGFL(DX1,DY1,DX2,DY2)
      DOUBLE PRECISION DX1
      DOUBLE PRECISION DX2
      DOUBLE PRECISION DY1
      DOUBLE PRECISION DY2
      RETURN
      END
      SUBROUTINE PLSECO(RED,GHREEN,BLUE)
      DOUBLE PRECISION RED
      DOUBLE PRECISION GREEN
      DOUBLE PRECISION BLUE
      RETURN
      END
      SUBROUTINE PLSEPA(INDEX)
      RETURN
      END
      SUBROUTINE PLTXTH(IFONT,ISTRNG,XPOS,YPOS,IJUSTH,IJUSTV,
     1                  PHEIGH,IERROR)
      INTEGER ISTRNG(*)
      INTEGER IFONT(*)
      INTEGER IJUSTH
      INTEGER IJUSTV
      INTEGER IERROR
      DOUBLE PRECISION XPOS
      DOUBLE PRECISION YPOS
      DOUBLE PRECISION PHEIGH
      RETURN
      END
      SUBROUTINE PLTXTV(IFONT,ISTRNG,XPOS,YPOS,IJUSTH,IJUSTV,
     1                  PHEIGH,IERROR)
      INTEGER ISTRNG(*)
      INTEGER IFONT(*)
      INTEGER IJUSTH
      INTEGER IJUSTV
      INTEGER IERROR
      DOUBLE PRECISION XPOS
      DOUBLE PRECISION YPOS
      DOUBLE PRECISION PHEIGH
      RETURN
      END
      SUBROUTINE PLINIT(ITYPE,IERROR,IADE,PROT,IADE2)
      DOUBLE PRECISION PROT
      INTEGER ITYPE
      INTEGER IERROR
      INTEGER IADE(*)
      INTEGER IADE2(*)
      WRITE(*,*) ' THE LIBPLOT DRIVER HAVE NOT BEEN INSTALLED AT YOUR'
      WRITE(*,*) ' SITE.  CONTACT YOUR LOCAL SITE COORDINATER FOR '
      WRITE(*,*) ' MORE INFORMATION'
      IERROR=1
      RETURN
      END
      SUBROUTINE PLERAS(IADE,IRED,IGREEN,IBLUE)
      INTEGER IADE(*)
      RETURN
      END
